Installation
--------------

``binarymap`` requires Python 3.8 or higher.

The easiest way to install ``binarymap`` is from `PyPI <https://pypi.org/>`_ using `pip <https://pip.pypa.io>`_ with::

    pip install binarymap

The source code for ``binarymap`` is available on GitHub at https://github.com/jbloomlab/binarymap.
